@@ -1,13 +1,11 @@
 # MIT licensed
-# Copyright (c) 2013-2017 lilydjwg <lilydjwg@gmail.com>, et al.
+# Copyright (c) 2013-2020 lilydjwg <lilydjwg@gmail.com>, et al.
 
 import json
 from urllib.parse import urlencode
 
 from tornado.httpclient import AsyncHTTPClient, HTTPRequest, HTTPResponse
 from tornado.httpclient import HTTPError
-from tornado.platform.asyncio import AsyncIOMainLoop, to_asyncio_future
-AsyncIOMainLoop().install()
 
 try:
   import pycurl
@@ -19,7 +17,6 @@ from .httpclient import DEFAULT_USER_AGENT
 
 __all__ = ['session', 'HTTPError', 'NetworkErrors']
 
-client = AsyncHTTPClient()
 HTTP2_AVAILABLE = None if pycurl else False
 
 def try_use_http2(curl):
@@ -34,6 +31,12 @@ def try_use_http2(curl):
     curl.setopt(pycurl.HTTP_VERSION, 4)
 
 class Session:
+  def post(self, url, **kwargs):
+    j = kwargs.pop('json', None)
+    if j:
+      kwargs['body'] = json.dumps(j)
+    return self.get(url, method='POST', **kwargs)
+
   def get(self, url, **kwargs):
     kwargs['prepare_curl_callback'] = try_use_http2
 
@@ -62,7 +65,7 @@ class ResponseManager:
     self.req = req
 
   async def __aenter__(self):
-    return await to_asyncio_future(client.fetch(self.req))
+    return await AsyncHTTPClient().fetch(self.req)
 
   async def __aexit__(self, exc_type, exc, tb):
     pass
